==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/StraightNumericAxisBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { NumericAxisBaseDescriptionMetadata } from "./NumericAxisBaseDescriptionMetadata";
/**
 * @hidden
 */
var StraightNumericAxisBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(StraightNumericAxisBaseDescriptionMetadata, _super);
    function StraightNumericAxisBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StraightNumericAxisBaseDescriptionMetadata.b = function (a) {
        if (StraightNumericAxisBaseDescriptionMetadata.a == null) {
            StraightNumericAxisBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StraightNumericAxisBaseDescriptionMetadata.c(StraightNumericAxisBaseDescriptionMetadata.a);
        }
        if (a.j(StraightNumericAxisBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(StraightNumericAxisBaseDescriptionMetadata.a);
    };
    StraightNumericAxisBaseDescriptionMetadata.c = function (a) {
        NumericAxisBaseDescriptionMetadata.c(a);
        a.item("ScaleMode", "ExportedType:string:NumericScaleMode");
        a.item("ScaleMode@names", "Linear;Logarithmic");
    };
    StraightNumericAxisBaseDescriptionMetadata.d = function (a) {
        StraightNumericAxisBaseDescriptionMetadata.b(a);
        a.z("StraightNumericAxisBase", StraightNumericAxisBaseDescriptionMetadata.a);
    };
    StraightNumericAxisBaseDescriptionMetadata.$t = markType(StraightNumericAxisBaseDescriptionMetadata, 'StraightNumericAxisBaseDescriptionMetadata');
    StraightNumericAxisBaseDescriptionMetadata.a = null;
    return StraightNumericAxisBaseDescriptionMetadata;
}(Base));
export { StraightNumericAxisBaseDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/StraightNumericAxisBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { NumericAxisBaseDescriptionMetadata } from "./NumericAxisBaseDescriptionMetadata";
/**
 * @hidden
 */
var StraightNumericAxisBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(StraightNumericAxisBaseDescriptionMetadata, _super);
    function StraightNumericAxisBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StraightNumericAxisBaseDescriptionMetadata.b = function (a) {
        if (StraightNumericAxisBaseDescriptionMetadata.a == null) {
            StraightNumericAxisBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StraightNumericAxisBaseDescriptionMetadata.c(StraightNumericAxisBaseDescriptionMetadata.a);
        }
        if (a.k(StraightNumericAxisBaseDescriptionMetadata.a)) {
            return;
        }
        a.aa(StraightNumericAxisBaseDescriptionMetadata.a);
    };
    StraightNumericAxisBaseDescriptionMetadata.c = function (a) {
        NumericAxisBaseDescriptionMetadata.c(a);
        a.item("ScaleMode", "ExportedType:string:NumericScaleMode");
        a.item("ScaleMode@names", "Linear;Logarithmic");
    };
    StraightNumericAxisBaseDescriptionMetadata.d = function (a) {
        StraightNumericAxisBaseDescriptionMetadata.b(a);
        a.ab("StraightNumericAxisBase", StraightNumericAxisBaseDescriptionMetadata.a);
    };
    StraightNumericAxisBaseDescriptionMetadata.$t = markType(StraightNumericAxisBaseDescriptionMetadata, 'StraightNumericAxisBaseDescriptionMetadata');
    StraightNumericAxisBaseDescriptionMetadata.a = null;
    return StraightNumericAxisBaseDescriptionMetadata;
}(Base));
export { StraightNumericAxisBaseDescriptionMetadata };
